package org.fluttercode.demo.fastload.fastapp;

import java.util.ArrayList;
import java.util.List;

import javax.enterprise.context.RequestScoped;
import javax.faces.context.FacesContext;
import javax.inject.Named;

@Named
@RequestScoped
public class DataBean {

	// indicates the page we are on
	private int pageNumber = 0;

	// lazy loaded reference to the results
	private List<Integer> data;

	// returns the list of data by lazy loading it
	public List<Integer> getData() {
		if (data == null) {
			data = generateData();
		}
		return data;
	}

	// generates the list of data, think of this as an expensive DB operation
	private List<Integer> generateData() {

		//enable this to prevent restore view data fetches
		/*if (!FacesContext.getCurrentInstance().getRenderResponse()) {
			return null;
		}*/

		System.out.println("Generating Data starting from " + pageNumber);

		// Sleep for 2 seconds while I access the database and do stuff
		try {
			Thread.sleep(2000);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}

		// now we actually generate the data
		List<Integer> results = new ArrayList<Integer>();
		for (int i = 0; i < 10; i++) {
			results.add(pageNumber + i);
		}
		return results;

	}

	// method to move to the next page in the list
	public void nextPage() {
		pageNumber = pageNumber + 10;
		// invalidate the lazy loaded data
		data = null;
	}

	// method to move to the previous page in the list
	public void previousPage() {
		pageNumber = pageNumber - 10;
		// invalidate the lazy loaded data
		data = null;
	}

	// getter/setter for page number
	public int getPageNumber() {
		return pageNumber;
	}

	public void setPageNumber(int pageNumber) {
		this.pageNumber = pageNumber;
	}
}
